@@ -1,6 +1,6 @@
 import os
+import shutil
 from pathlib import Path
-from tempfile import TemporaryDirectory
 from types import SimpleNamespace
 from uuid import uuid4
 
@@ -8,8 +8,11 @@ from dotenv import load_dotenv
 
 load_dotenv()
 
-TEMPDIR = TemporaryDirectory(dir=Path(__file__).parents[1], prefix="webapp-")
-SAVEDIR = Path(TEMPDIR.name) if os.getenv("SAVEDIR") is None else Path(os.getenv("SAVEDIR", ""))
+BASE_SAVEDIR = (
+    Path(__file__).resolve().parents[1] / "webapp-temp"
+    if (base_savedir := os.getenv("SAVEDIR")) is None
+    else Path(base_savedir)
+)
 MAX_ARTICLES = 1000
 DATA_FILENAME = {
     "graph": "G.pkl",
@@ -28,15 +31,13 @@ def generate_session_id():
 
 def get_data_savepath(session_id: str):
     savepath = {}
-    savedir = SAVEDIR / session_id
+    savedir = BASE_SAVEDIR / session_id
     savedir.mkdir(parents=True, exist_ok=True)
     for file, filepath in DATA_FILENAME.items():
         savepath[file] = str(savedir / filepath)
     return savepath
 
 
-def clean_up_files():
-    try:
-        TEMPDIR.cleanup()
-    except Exception:
-        pass
+def cleanup_tempdir():
+    if os.getenv("SAVEDIR") is None:
+        shutil.rmtree(BASE_SAVEDIR, ignore_errors=True)
